sobjects/notification.py
branchtls-sprint
changeset 1723 30c3a713ab61
parent 1477 b056a49c16dc
child 1977 606923dff11b
--- a/sobjects/notification.py	Mon May 11 11:30:42 2009 +0200
+++ b/sobjects/notification.py	Mon May 11 11:55:10 2009 +0200
@@ -198,8 +198,9 @@
             # since the same view (eg self) may be called multiple time and we
             # need a fresh stream at each iteration, reset it explicitly
             self.w = None
-            # call dispatch before subject to set .row/.col attributes on the view :/
-            content = self.dispatch(row=0, col=0, **kwargs)
+            # XXX call render before subject to set .row/.col attributes on the
+            #     view
+            content = self.render(row=0, col=0, **kwargs)
             subject = self.subject()
             msg = format_mail(userdata, [emailaddr], content, subject,
                               config=self.config, msgid=msgid, references=refs)